package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;

import org.w3c.dom.Element;

/**
 * Reads multi layer marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private MultiLayerMarkerSymbol symbol;

    public MultiLayerMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerMarkerSymbol) {
            this.symbol = (MultiLayerMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerMarkerSymbol!");
        }
    }

    public MultiLayerMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerMarkerSymbol) {
            this.symbol = (MultiLayerMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read() {
        logger.debug("read()");
        try {
            for(int i = 0; i < symbol.getLayerCount(); i++) {
                ISymbol sym = (ISymbol)symbol.getLayer(i);
                ISymbolReader sreader = new MarkerSymbolReader(sym);
                sreader.setParent(parent);
                sreader.setUtil(util);
                sreader.read();
            }
        }
        catch(Exception e) {
            logger.error(
                "Could not read symbol " +
                symbol.getClass().toString());
        }
        return parent;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
